@@ -51,16 +51,15 @@ void FavoriteListView::update()
         m_prevquery = "";
     }
 
-    const QDict<Kita::Thread>& threads = FavoriteThreads::getInstance() ->threads();
-    //  FavoriteThreads::const_iterator it;
+    const QValueList<QString> threadList = FavoriteThreads::getInstance() -> threadList();
 
     subjectList->clear();
 
     KitaThreadInfo* cache = KitaThreadInfo::getInstance();
 
-    QDictIterator<Kita::Thread> it( threads );
-    for ( ; it.current(); ++it ) {
-        const Kita::Thread* thread = it.current();
+    QValueList<QString>::const_iterator it;
+    for ( it = threadList.begin(); it != threadList.end(); ++it ) {
+        const Kita::Thread* thread = Kita::Thread::getByURL( *it );
 
         QDateTime since;
         since.setTime_t( KURL( thread->datURL() ).fileName().section( '.', 0, 0 ).toInt() );
@@ -87,15 +86,14 @@ void FavoriteListView::loadThread( QListViewItem* item )
 {
     if ( ! item ) return ;
 
-    const QDict<Kita::Thread>& threads = FavoriteThreads::getInstance() ->threads();
-    //  FavoriteThreads::const_iterator it;
+    const QValueList<QString> threadList = FavoriteThreads::getInstance() -> threadList();
 
-    QDictIterator<Kita::Thread> it( threads );
-    for ( ; it.current(); ++it ) {
-        const Kita::Thread* thread = it.current();
+    QValueList<QString>::const_iterator it;
+    for ( it = threadList.begin(); it != threadList.end(); ++it ) {
+        const Kita::Thread* thread = Kita::Thread::getByURL( *it );
 
         if ( thread->datURL() == item->text( Col_DatURL ) ) {
-            emit signalShowThread( thread );
+            emit showThreadRequested( thread, false );
         }
     }
 }
@@ -133,7 +131,7 @@ void FavoriteListView::slotContextMenuRequested( QListViewItem* item, const QPoi
         KRun::runURL( thread->url(), "text/html" );
         break;
     case 1:
-        emit signalShowThreadWithNewTab( thread );
+        emit showThreadRequested( thread, true );
         break;
     case 2:
         clipboard->setText( thread->name() + "\n" + thread->url() );
