@@ -59,8 +59,7 @@ signals:
     /**
      * @param thread ɽ륹
      */
-    void signalShowThread( const Kita::Thread* thread );
-    void signalShowThreadWithNewTab( const Kita::Thread* thread );
+    void showThreadRequested( const Kita::Thread* thread, bool withNewTab );
 };
 
 #endif
