@@ -68,7 +68,7 @@ KitaMainWindow::KitaMainWindow()
 
     // load favorite boards;
     loadFavoriteBoards();
-    
+
     // load completion
     loadCompletion();
 
@@ -137,7 +137,7 @@ KitaMainWindow::~KitaMainWindow()
     saveCompletion();
 
     saveFavoriteBoards();
-    
+
     saveFavorites();
 
     saveCache();
@@ -215,7 +215,7 @@ void KitaMainWindow::setupActions()
                        i18n( "URL Line" ),
                        0,
                        this,
-                       SLOT( slotUrlLine() )       /* dummy */,
+                       SLOT( slotUrlLine() )        /* dummy */,
                        actionCollection(), "url_line_action" );
 
     KStdAction::keyBindings( this, SLOT( optionsConfigureKeys() ), actionCollection() );
@@ -243,6 +243,13 @@ void KitaMainWindow::setupActions()
                  actionCollection(),
                  "close_tab" );
 
+    new KAction( i18n( "reset windows" ),
+                 0,
+                 this,
+                 SLOT( resetWindows() ),
+                 actionCollection(),
+                 "reset_win" );
+
     createGUI();
 }
 
@@ -392,21 +399,27 @@ void KitaMainWindow::newToolbarConfig()
 void KitaMainWindow::windowShowBoardlist()
 {
     if ( m_boardListAction->isChecked() ) {
-        m_boardDock->show();
+        makeDockVisible( m_boardDock );
     } else {
-        m_boardDock->hide();
+        makeDockInvisible( m_boardDock );
     }
 }
 
 void KitaMainWindow::windowShowSubjectlist()
 {
     if ( m_subjectListAction->isChecked() ) {
-        m_subjectDock->show();
+        makeDockVisible( m_subjectDock );
     } else {
-        m_subjectDock->hide();
+        makeDockInvisible( m_subjectDock );
     }
 }
 
+void KitaMainWindow::resetWindows()
+{
+    m_boardDock->manualDock( m_mainDock, KDockWidget::DockLeft, 20 );
+    m_subjectDock->manualDock( m_mainDock, KDockWidget::DockTop, 30 );
+}
+
 void KitaMainWindow::windowMenuAboutToShow()
 {
     m_boardListAction->setChecked( m_boardDock->isVisible() );
@@ -461,30 +474,29 @@ void KitaMainWindow::changeCaption( const QString& text )
 
 void KitaMainWindow::setupView()
 {
-    KDockWidget * mainDock;
-    mainDock = createDockWidget( "main", 0L, 0L, i18n( "main" ) );
-    m_threadTab = new KitaThreadTabWidget( mainDock );
-    mainDock->setWidget( m_threadTab );
-    mainDock->setDockSite( KDockWidget::DockFullSite );
-    mainDock->setEnableDocking( KDockWidget::DockNone );
+    m_mainDock = createDockWidget( "main", 0L, 0L, i18n( "main" ) );
+    m_threadTab = new KitaThreadTabWidget( m_mainDock );
+    m_mainDock->setWidget( m_threadTab );
+    m_mainDock->setDockSite( KDockWidget::DockFullSite );
+    m_mainDock->setEnableDocking( KDockWidget::DockNone );
     connect( m_threadTab, SIGNAL( openURLRequest( const KURL&, const KParts::URLArgs& ) ),
              SLOT( slotOpenURLRequest( const KURL&, const KParts::URLArgs& ) ) );
 
     m_subjectDock = createDockWidget( "subject", 0L, 0L, i18n( "subject" ) );
     m_subjectTab = new KitaSubjectTabWidget( m_subjectDock );
     m_subjectDock->setWidget( m_subjectTab );
-    m_subjectDock->setDockSite( KDockWidget::DockFullSite );
+    m_subjectDock->setDockSite( KDockWidget::DockNone );
 
     m_boardDock = createDockWidget( "board", 0L, 0L, i18n( "board" ) );
     m_boardView = new KitaBoardView( m_boardDock );
     m_boardDock->setWidget( m_boardView );
-    m_boardDock->setDockSite( KDockWidget::DockFullSite );
+    m_boardDock->setDockSite( KDockWidget::DockNone );
 
-    setView( mainDock );
-    setMainDockWidget( mainDock );
+    setView( m_mainDock );
+    setMainDockWidget( m_mainDock );
 
-    m_boardDock->manualDock( mainDock, KDockWidget::DockLeft, 20 );
-    m_subjectDock->manualDock( mainDock, KDockWidget::DockTop, 30 );
+    m_boardDock->manualDock( m_mainDock, KDockWidget::DockLeft, 20 );
+    m_subjectDock->manualDock( m_mainDock, KDockWidget::DockTop, 30 );
 }
 
 void KitaMainWindow::slotOpenURLRequest( const KURL& url, const KParts::URLArgs& )
@@ -560,7 +572,7 @@ void KitaMainWindow::loadFavorites()
     if ( file.open( IO_ReadOnly ) ) {
         QTextStream stream( &file );
         stream.setEncoding( QTextStream::UnicodeUTF8 );
-        
+
         QString xml = stream.read();
         FavoriteThreads::readFromXML( xml );
     }
@@ -637,7 +649,7 @@ void KitaMainWindow::loadFavoriteBoards()
     if ( file.open( IO_ReadOnly ) ) {
         QTextStream stream( &file );
         stream.setEncoding( QTextStream::UnicodeUTF8 );
-        
+
         QString xml = stream.read();
         Kita::FavoriteBoards::readFromXML( xml );
     }
