@@ -101,6 +101,7 @@ private slots:
     void settingsMenuAboutToShow();
     void settingsShowMailAddress();
     void slotEditCopy();
+    void resetWindows();
 
     void changeStatusbar( const QString& text );
     void changeCaption( const QString& text );
@@ -126,6 +127,7 @@ private:
     KToggleAction* m_subjectListAction;
     KToggleAction* m_showAddressAction;
 
+    KDockWidget* m_mainDock;
     KDockWidget* m_boardDock;
     KDockWidget* m_subjectDock;
 
