@@ -186,7 +186,11 @@ void KitaBoardView::loadBoard( QListViewItem* item )
         return ;
     }
 
-    emit openBoardRequested( boardURL, false );
+    if ( KitaConfig::alwaysUseTab() ) {
+        emit openBoardRequested( boardURL, true );
+    } else {
+        emit openBoardRequested( boardURL, false );
+    }
 }
 
 void KitaBoardView::setFont( const QFont& font )
@@ -248,7 +252,11 @@ void KitaBoardView::slotMouseButtonClicked( int button, QListViewItem* item )
         emit openBoardRequested( boardURL, true );
         break;
     case LeftButton:
-        emit openBoardRequested( boardURL, false );
+        if ( KitaConfig::alwaysUseTab() ) {
+            emit openBoardRequested( boardURL, true );
+        } else {
+            emit openBoardRequested( boardURL, false );
+        }
         break;
     }
 }
