@@ -36,7 +36,9 @@ public slots:
 private:
     FavoriteListView* m_favoriteList;
     KitaSubjectView* m_latestView;
+    QPtrList<KitaSubjectView> m_viewList;
     void connectSignals( Kita::ThreadListView* );
+    KitaSubjectView* findView( const QString& boardURL );
 
 private slots:
     void slotCurrentChanged( QWidget* widget );
