@@ -38,6 +38,7 @@
 #include "libkita/thread.h"
 #include "libkita/kita_misc.h"
 #include "part/kita2ch.h"
+#include "kitaconfig.h"
 
 KitaSubjectView::KitaSubjectView( QWidget* parent, const char* name )
         : Kita::ThreadListView( parent, name )
@@ -83,13 +84,18 @@ void KitaSubjectView::loadThread( QListViewItem* item )
 
     Kita::Thread* thread = Kita::Thread::getByURL( datURL.url() );
 
-    emit showThreadRequested( thread, false );
+    if ( KitaConfig::alwaysUseTab() ) {
+        emit showThreadRequested( thread, true );
+    } else {
+        emit showThreadRequested( thread, false );
+    }
 }
 
 void KitaSubjectView::loadBoard( const Kita::Board* board )
 {
     setActiveWindow();
     topLevelWidget() ->raise();
+    QDateTime currentdat = QDateTime::currentDateTime();
 
     // reset member variables.
     // FIXME: FavoriteListView::update()˥ԡ
@@ -127,16 +133,32 @@ void KitaSubjectView::loadBoard( const Kita::Board* board )
         item->setText( Col_DatURL, thread->datURL() );
 
         // FIXME: updateThread˥ԡƤ
+        // TODO: 'N'Υ
+        /*
+        ͥ
+        0: ɤ1000ĶƤ
+        1: ̤1ʾФäƤ
+        2: ̤1Τ
+        3: ɤ1000ʲΤ
+        4: ̤ɤ
+        */
         if ( readNum > 0 && resNum != readNum ) {
             // ̤ɤ
             item->setPixmap( Col_Mark, SmallIcon( "unread" ) );
-            item->setText( Col_MarkOrder, "2" );
+            item->setText( Col_MarkOrder, "4" );
         } else if ( readNum > 0 ) {
             // 
             item->setPixmap( Col_Mark, SmallIcon( "read" ) );
-            item->setText( Col_MarkOrder, "1" );
+            if( readNum > 1000 ) {
+                item->setText( Col_MarkOrder, "0" );
+            } else {
+                item->setText( Col_MarkOrder, "3" );
+            }
+        } else if ( since.secsTo( currentdat ) < 3600*24 ){
+            item->setPixmap( Col_Mark, SmallIcon( "newthread" ) );
+            item->setText( Col_MarkOrder, "2" );
         } else {
-            item->setText( Col_MarkOrder, "0" );
+            item->setText( Col_MarkOrder, "1" );
         }
     }
 
@@ -230,7 +252,11 @@ void KitaSubjectView::slotMouseButtonClicked( int button, QListViewItem* item )
         emit showThreadRequested( thread, true );
         break;
     case LeftButton:
-        emit showThreadRequested( thread, false );
+        if ( KitaConfig::alwaysUseTab() ) {
+            emit showThreadRequested( thread, true );
+        } else {
+            emit showThreadRequested( thread, false );
+        }
         break;
     }
 }
