@@ -44,10 +44,13 @@ public slots:
     void deleteView( KitaThreadView* );
     void reloadThread();
     void focusSearchCombo();
+    void slotCurrentChanged( QWidget* );
 
 private:
     void connectSignals( KitaThreadView* );
     KitaThreadView* createView();
+    QPtrList<KitaThreadView> m_viewList;
+    KitaThreadView* findView( const QString& threadURL );
 
 private slots:
     void slotOpenURLRequest( const KURL& url, const KParts::URLArgs& args = KParts::URLArgs() );
