@@ -12,6 +12,7 @@
 #include "thread.h"
 #include "qcp932codec.h"
 #include "cache.h"
+#include "threadinfo.h"
 
 #include <config.h>
 
@@ -31,71 +32,10 @@
 
 #include <qregexp.h>
 #include <qfile.h>
+#include <qmessagebox.h>
 
 using namespace Kita;
 
-bool Access::readCacheHeader( FILE* fs, const KURL& url )
-{
-    QFile file;
-    file.open( IO_ReadOnly, fs );
-
-    char buffer[ 401 ];
-
-    // CacheRevision
-    if ( file.readLine( buffer, 400 ) == -1 ) {
-        return false;
-    }
-    if ( strcmp( buffer, "7\n" ) != 0 ) {
-        return false;
-    }
-
-    // URL
-    if ( file.readLine( buffer, 400 ) == -1 ) {
-        return false;
-    }
-
-    int l = strlen( buffer );
-    if ( l > 0 ) {
-        buffer[ l - 1 ] = 0; // Strip newline
-    }
-
-    if ( url.url() != buffer ) {
-        return false; // Hash collision
-    }
-
-    // Creation Date
-    if ( file.readLine( buffer, 400 ) == -1 ) {
-        return false;
-    }
-
-    // Expiration Date
-    if ( file.readLine( buffer, 400 ) == -1 ) {
-        return false;
-    }
-
-    // ETag
-    if ( file.readLine( buffer, 400 ) == -1 ) {
-        return false;
-    }
-
-    // Last-Modified
-    if ( file.readLine( buffer, 400 ) == -1 ) {
-        return false;
-    }
-
-    // Mime-Type
-    if ( file.readLine( buffer, 400 ) == -1 ) {
-        return false;
-    }
-
-    // Charset
-    if ( file.readLine( buffer, 400 ) == -1 ) {
-        return false;
-    }
-
-    return true;
-}
-
 // copied from http.cc
 // å夬ȤϤƤmallocΰ˥ԡ֤
 // å夬ʤȤ0֤
@@ -108,63 +48,50 @@ QCString Access::getCacheData( const KURL& url )
         return 0;
     }
 
-    if ( readCacheHeader( fs, url ) ) {
-        struct stat buf;
-        ::stat( QFile::encodeName( cachePath ), &buf );
-        int pos = ftell( fs );
-        int datasize = buf.st_size - pos;
-
-        char* ret = static_cast<char *>( malloc( datasize + 1 ) );
-        fread( ret, datasize, 1, fs );
-        ret[ datasize ] = '\0';
-        fclose( fs );
-        return ret;
-    }
+    struct stat buf;
+    ::stat( QFile::encodeName( cachePath ), &buf );
+    int pos = ftell( fs );
+    int datasize = buf.st_size - pos;
 
+    char* ret = static_cast<char *>( malloc( datasize + 1 ) );
+    fread( ret, datasize, 1, fs );
+    ret[ datasize ] = '\0';
     fclose( fs );
-    unlink( QFile::encodeName( cachePath ) );
-    return 0;
+    return ret;
 }
 
 // å˽񤭹ߡ
 // partial dataäƤΤǤ񤭴롣
 void Access::writeCacheData( const KURL& url )
 {
+    if ( m_orgData.isNull() && responseCode() == 304 ) {
+        m_threadData = QString::null;
+        m_orgData = m_threadData;
+        return ;
+    } else if ( ! m_orgData.isNull() && responseCode() == 304 ) {
+        m_threadData = m_orgData;
+        return ;
+    } else if ( ! m_orgData.isNull() && responseCode() == 206 ) {
+        QCString orgData = QCString( m_orgData, m_orgData.length() );
+        m_threadData = orgData + m_threadData;
+    }
+    m_orgData = m_threadData;
+
     QString cachePath = Kita::Cache::getPath( url );
+    FILE *fs = fopen( QFile::encodeName( cachePath ), "w" );
+    if ( !fs ) return ;
 
-    FILE *fs = fopen( QFile::encodeName( cachePath ), "r+" );
-    if ( !fs ) {
-        return ;
-    }
-
-    if ( readCacheHeader( fs, url ) ) {
-        if ( ! m_orgData.isNull() && responseCode() == 304 ) {
-            // dat餷
-            m_threadData = m_orgData;
-        } else if ( ! m_orgData.isNull() && responseCode() == 206 ) {
-            QCString orgData = QCString( m_orgData, m_orgData.length() );
-            m_threadData = orgData + m_threadData;
-        }
-        fwrite( m_threadData, m_threadData.size(), 1, fs );
-        fclose( fs );
-
-        m_orgData.truncate( 0 );
-        return ;
-    }
-
+    fwrite( m_threadData, m_threadData.size(), 1, fs );
     fclose( fs );
-    unlink( QFile::encodeName( cachePath ) );
+
     return ;
 }
 
-QString Access::get()
+QString Access::getupdate()
 {
-    m_orgData = getCacheData( m_thread->datURL() );
 
-    // copy original cache file
-    QString cachePath = Kita::Cache::getPath( m_thread->datURL() );
-    QString backupPath = cachePath + ".kita_backup";
-    KIO::NetAccess::copy( cachePath, backupPath );
+    QString retstr;
+    m_threadData = "";
 
     if ( KURL( m_thread->datURL() ).protocol() != "k2ch" ) {
         KIO::SlaveConfig::self() ->setConfigData( "http",
@@ -179,7 +106,6 @@ QString Access::get()
     connect( job, SIGNAL( data( KIO::Job*, const QByteArray& ) ),
              SLOT( slotReceiveThreadData( KIO::Job*, const QByteArray& ) ) );
     connect( job, SIGNAL( result( KIO::Job* ) ), SLOT( slotThreadResult( KIO::Job* ) ) );
-    connect( job, SIGNAL( redirection( KIO::Job *, const KURL& ) ), SLOT( slotRedirection( KIO::Job *, const KURL& ) ) );
 
     // use 'HTTP-Headers' metadata.
     job->addMetaData( "PropagateHttpHeader", "true" );
@@ -190,11 +116,35 @@ QString Access::get()
 
     enter_loop();
 
-    writeCacheData( m_thread->datURL() );
-    KIO::NetAccess::del( backupPath );
+    if ( m_threadData.length() ) {
+        QCp932Codec codec;
+        retstr = codec.toUnicode( m_threadData );
 
-    QCp932Codec codec;
-    return codec.toUnicode( m_threadData );
+        KURL url = m_thread->datURL();
+
+        url.setProtocol( "k2ch" );
+        
+        // mkdir: $(KDRDIR)/share/cache/kita/pc.2ch.net/linux/xxxx.dat
+        // ξ硢kita, pc.2ch.net, linux
+        // TODO: 3ؤޤǤбƤʤΤʤȤ롣
+        QString cachePath = Kita::Cache::getPath( url );
+        KURL cacheDir = KURL( cachePath, "." );
+        KURL cacheDir2 = KURL( cacheDir, ".." );
+        KURL cacheDir3 = KURL( cacheDir2, ".." );
+        if ( !KIO::NetAccess::exists( cacheDir3 ) ) {
+            KIO::NetAccess::mkdir( cacheDir3 );
+        }
+        if ( !KIO::NetAccess::exists( cacheDir2 ) ) {
+            KIO::NetAccess::mkdir( cacheDir2 );
+        }
+        if ( !KIO::NetAccess::exists( cacheDir ) ) {
+            KIO::NetAccess::mkdir( cacheDir );
+        }
+
+        writeCacheData( url );
+    } else retstr = "";
+
+    return retstr;
 }
 
 // from netaccess.cpp
@@ -210,15 +160,6 @@ void Access::enter_loop()
     qt_leave_modal( &dummy );
 }
 
-void Access::slotRedirection( KIO::Job *, const KURL & newURL )
-{
-    // datƤȻפΤǥå򸵤᤹
-    QString cachePath = Kita::Cache::getPath( m_thread->datURL() );
-    QString backupPath = cachePath + ".kita_backup";
-    KIO::NetAccess::copy( backupPath, cachePath );
-    KIO::NetAccess::del( backupPath );
-}
-
 void Access::slotReceiveThreadData( KIO::Job*, const QByteArray& data )
 {
     QCString cstr( data.data(), data.size() + 1 );
@@ -276,4 +217,43 @@ int Access::responseCode()
     }
 }
 
+QString Access::getcache()
+{
+    KURL url = m_thread->datURL();
+    url.setProtocol( "k2ch" );
+
+    m_orgData = getCacheData( url );
+
+    QCp932Codec codec;
+    return codec.toUnicode( m_orgData );
+
+}
+
+QString Access::get()
+{
+    QString ret;
+    ret = getcache() + getupdate();
+
+    return ret;
+}
+
+bool Access::deleteLog( const Thread* thread, QWidget* parent )
+{
+    if ( QMessageBox::warning( parent,
+                               "Kita",
+                               "Do you want to delete Log ?",
+                               QMessageBox::Ok, QMessageBox::Cancel | QMessageBox::Default )
+            == QMessageBox::Ok ) {
+
+        KURL url = thread->datURL();
+        QString str = Kita::Cache::getPath( url );
+        KIO::NetAccess::del( str );
+
+        url.setProtocol( "k2ch" );
+        str = Kita::Cache::getPath( url );
+        return KIO::NetAccess::del( str );
+    }
+    return FALSE;
+}
+
 #include "access.moc"
