@@ -15,7 +15,8 @@
 
 class KURL;
 
-namespace KIO {
+namespace KIO
+{
     class Job;
 }
 
@@ -31,19 +32,21 @@ namespace Kita
         Q_OBJECT
 
     public:
-        Access( const Thread* thread ) : m_thread( thread ) {};
+        Access( const Thread* thread ) : m_thread( thread ), m_currentJob( 0 ) {};
         ~Access() {};
 
         QString get();
         void killJob();
         int serverTime();
+        QString getcache();
+        QString getupdate();
+        int responseCode();
+        static bool deleteLog( const Thread* thread, QWidget* parent );
 
     private:
-        void enter_loop();
         QCString getCacheData( const KURL& url );
         void writeCacheData( const KURL& url );
-        int responseCode();
-        bool readCacheHeader( FILE* fs, const KURL& url );
+        void enter_loop();
 
         const Thread* m_thread;
         KIO::Job* m_currentJob;
@@ -53,7 +56,6 @@ namespace Kita
 
     private slots:
         void slotReceiveThreadData( KIO::Job* job, const QByteArray& data );
-        void slotRedirection( KIO::Job* job, const KURL& );
         void slotThreadResult( KIO::Job* job );
 
     signals:
