@@ -23,8 +23,6 @@ namespace Kita
     class Cache
     {
         static QString baseDir( const KURL& url );
-        static QString subDir( const QString& host );
-        static QString hashString( const KURL& url );
     public:
         static QString getPath( const KURL& url );
     };
