@@ -16,6 +16,22 @@
 
 using namespace Kita;
 
+CommentList::CommentList( const QString& str )
+{
+    QStringList lines = QStringList::split( "\n", str );
+    for ( QStringList::iterator it = lines.begin(); it != lines.end(); ++it ) {
+        QString line = ( *it );
+        if ( line.isEmpty() ) {
+            continue;
+        }
+        Kita::Comment comment( line );
+        m_list << comment;
+    }
+}
+
+CommentList::~CommentList()
+{}
+
 Comment::Comment() : m_isValid( false )
 {}
 
