@@ -22,6 +22,8 @@ class BoardTest : public CppUnit::TestFixture {
     CPPUNIT_TEST( testName );
     CPPUNIT_TEST( testSubjectTxtURL );
     CPPUNIT_TEST( testURL );
+    CPPUNIT_TEST( testStaticName );
+    CPPUNIT_TEST( testReplace );
     CPPUNIT_TEST_SUITE_END();
 
     Kita::Board *m_normal, *m_share1, *m_share2, *m_share3, *m_null;
@@ -34,6 +36,8 @@ public:
     void testName();
     void testSubjectTxtURL();
     void testURL();
+    void testStaticName();
+    void testReplace();
 };
 
 #endif
