@@ -19,6 +19,8 @@
 #include "misctest.h"
 #include "favoritethreadstest.h"
 #include "favoriteboardstest.h"
+#include "commentlisttest.h"
+#include "cachetest.h"
 
 int main( int argc, char* argv[] )
 {
@@ -32,6 +34,8 @@ int main( int argc, char* argv[] )
   runner.addTest( MiscTest::suite() );
   runner.addTest( FavoriteThreadsTest::suite() );
   runner.addTest( FavoriteBoardsTest::suite() );
+  runner.addTest( CommentListTest::suite() );
+  runner.addTest( CacheTest::suite() );
   runner.run( "" );
   return 0;
 }
