@@ -26,10 +26,11 @@ class ThreadTest : public CppUnit::TestFixture {
     CPPUNIT_TEST( testBoardName );
     CPPUNIT_TEST( testBoardURL );
     CPPUNIT_TEST( testBoardID );
+    CPPUNIT_TEST( testReplace );
     CPPUNIT_TEST_SUITE_END();
 
     Kita::Thread *m_normal;
-    Kita::Thread *m_fromxml, *m_fromxml2, *m_fromxml3;
+
 public:
     void setUp();
     void tearDown();
@@ -42,6 +43,7 @@ public:
     void testBoardName();
     void testBoardURL();
     void testBoardID();
+    void testReplace();
 };
 
 #endif
