@@ -25,6 +25,11 @@ void URLConvertTest::setUp()
     m_boardURL2 = "http://pc.2ch.net/linux";
     m_boardURL2_k2ch = "k2ch://pc.2ch.net/linux";
 
+    // FIXME: invalid dat url.
+    m_machibbsDatURL = "http://kanto.machi.to/kana/dat/1234567890.cgi";
+    
+    m_machibbsThreadURL = "http://kanto.machi.to/bbs/read.pl?BBS=kana&KEY=1234567890";
+    
     // relative path.
     m_cachePath = QString( "pc.2ch.net/linux/1022744633.dat" );
 }
@@ -36,6 +41,7 @@ void URLConvertTest::testDatToThread()
 {
     CPPUNIT_ASSERT_EQUAL( m_threadURL, Kita::datToThread( m_datURL ) );
     CPPUNIT_ASSERT_EQUAL( m_threadURL_k2ch, Kita::datToThread( m_datURL_k2ch ) );
+    CPPUNIT_ASSERT_EQUAL( m_machibbsThreadURL, Kita::datToThread( m_machibbsDatURL ) );
 }
 
 void URLConvertTest::testThreadToDat()
