@@ -65,6 +65,35 @@ void KitaThreadInfo::setResNum( const QString& url, int num )
   instance->m_resNumDict.insert( url, num );
 }
 
+void KitaThreadInfo::replace( const QString fromURL, const QString toURL )
+{
+    QMap<QString, int>::Iterator it;
+    KitaThreadInfo* instance = KitaThreadInfo::getInstance();
+    
+    for( it = instance->m_readDict.begin(); it != instance->m_readDict.end(); ++it ) {
+        QString url = it.key();
+        int num = it.data();
+        if ( url.find( fromURL ) == 0 ) {
+            url = url.replace( 0, fromURL.length(), toURL );
+            instance->m_readDict.erase( it );
+            instance->m_readDict.insert( url, num );
+            it = instance->m_readDict.begin(); // TODO äᤤˡ?
+        }
+    }
+
+    QMap<QString, int>::Iterator it2;
+    for( it2 = instance->m_resNumDict.begin(); it2 != instance->m_resNumDict.end(); ++it2 ) {
+        QString url = it2.key();
+        int num = it2.data();
+        if ( url.find( fromURL ) == 0 ) {
+            url = url.replace( 0, fromURL.length(), toURL );
+            instance->m_resNumDict.erase( it2 );
+            instance->m_resNumDict.insert( url, num );
+            it2 = instance->m_resNumDict.begin();
+        }
+    }
+}
+
 QDataStream& operator<<( QDataStream& s, KitaThreadInfo& c )
 {
   s << c.m_readDict;
