@@ -19,7 +19,7 @@
 #include <klocale.h>
 
 static const char *description =
-    I18N_NOOP("A KDE Application");
+    I18N_NOOP("Kita - 2ch client for KDE");
 
 static const char *version = VERSION;
 
@@ -33,8 +33,9 @@ static KCmdLineOptions options[] =
 int main(int argc, char **argv)
 {
     KAboutData about("kita", I18N_NOOP("Kita"), version, description,
-                     KAboutData::License_GPL, "(C) 2003 Hideki Ikemoto", 0, 0, "ikemo@users.sourceforge.jp");
-    about.addAuthor( "Hideki Ikemoto", 0, "ikemo@users.sourceforge.jp" );
+                     KAboutData::License_GPL, "(C) 2003-2004 Kita Developers", 0, 0, "ikemo@users.sourceforge.jp");
+    about.addAuthor( "Hideki Ikemoto", I18N_NOOP("maintainer, initial code"), "ikemo@users.sourceforge.jp" );
+    about.addAuthor( "konqueror plugin no hito", I18N_NOOP("konqueror plugin, KDE part"), "ogirin@users.sourceforge.jp");
     KCmdLineArgs::init(argc, argv, &about);
     KCmdLineArgs::addCmdLineOptions(options);
     KUniqueApplication app;
