@@ -23,7 +23,7 @@ KitaConfig* KitaConfig::getInstance()
 KitaConfig::KitaConfig()
         : m_threadColor( "black" ), m_threadBackgroundColor( "white" ),
         m_popupColor( "black" ), m_popupBackgroundColor( "yellow" ),
-        m_showMailAddress( false )
+        m_showMailAddress( false ), m_alwaysUseTab( false )
 {}
 
 KitaConfig::~KitaConfig()
