@@ -31,6 +31,10 @@ class KitaConfig
     KCompletion m_nameCompletion;
     QStringList m_asciiArtList;
     bool m_showMailAddress;
+    QStringList m_aboneNameList;
+    QStringList m_aboneIDList;
+    QStringList m_aboneWordList;
+    bool m_alwaysUseTab;
     KitaConfig();
     virtual ~KitaConfig();
 public:
@@ -56,6 +60,14 @@ public:
     static void setAsciiArtList( QStringList list ) { getInstance() ->m_asciiArtList = list; }
     static bool showMailAddress() { return getInstance() ->m_showMailAddress; }
     static void setShowMailAddresss( bool flag ) { getInstance() ->m_showMailAddress = flag; }
+    static QStringList& aboneNameList() { return getInstance() ->m_aboneNameList; }
+    static void setAboneNameList( QStringList list ) { getInstance() ->m_aboneNameList = list; }
+    static QStringList& aboneIDList() { return getInstance() ->m_aboneIDList; }
+    static void setIAboneIDList( QStringList list ) { getInstance() ->m_aboneIDList = list; }
+    static QStringList& aboneWordList() { return getInstance() ->m_aboneWordList; }
+    static void setAboneWordList( QStringList list ) { getInstance() ->m_aboneWordList = list; }
+    static bool alwaysUseTab() { return getInstance() ->m_alwaysUseTab; }
+    static void setAlwaysUseTab( bool on ) { getInstance() ->m_alwaysUseTab = on; }
 };
 
 #endif
