@@ -26,6 +26,10 @@ namespace Kita
 
 class KPopupMenu;
 
+#include <qstringlist.h>
+class KitaDomTree;
+class KitaThreadView;
+
 /**
 @author Hideki Ikemoto
 */
@@ -41,6 +45,12 @@ class KitaHTMLPart : public KHTMLPart
     int m_nextHit;
     QValueStack<QPoint> m_pointStack;
     KPopupMenu* m_popupMenu;
+    bool m_pushctrl;
+    bool m_pushmidbt;
+    KitaDomTree* m_domtree;
+    KitaThreadView* m_threadView;
+    Kita::Thread* m_thread;
+    QStringList m_anchorStack;
 
 public:
     int nextHit();
@@ -58,6 +68,14 @@ public:
     static QStringList lt_gt_spliter( const QString& input );
     void gotoURL( const Kita::Thread* thread, int prevResNum );
     void displayContents( const QString& input, const KURL& urlOfInput = 0 );
+    void setupEx( KitaThreadView* threadView, KitaDomTree* domtree,
+                  Kita::Thread* thread );
+    void gotoKokoyon();
+
+protected:
+    virtual void khtmlMousePressEvent( khtml::MousePressEvent* e );
+    virtual void khtmlMouseReleaseEvent( khtml::MouseReleaseEvent *e );
+    virtual void khtmlMouseMoveEvent( khtml::MouseMoveEvent* e );
 
 public slots:
     bool gobackAnchor();
