@@ -20,6 +20,7 @@
 
 #include "kita2ch.h"
 #include "libkita/thread.h"
+#include "kitadomtree.h"
 
 class KURL;
 class KitaHTMLPart;
@@ -35,6 +36,13 @@ namespace Kita
     class ResPopup;
 };
 
+/* mode , m_viewmode uses them. */
+enum{
+    VIEWMODE_PARENT,
+    VIEWMODE_KITANAVI,
+    VIEWMODE_PREVIEW
+};
+
 namespace KIO
 {
     class Job;
@@ -58,30 +66,77 @@ public:
     void killJob();
     void focusSearchCombo();
 
+    void setupEx( const Kita::Thread* thread,
+                  Kita::Access* access,
+                  KitaThreadView* viewparent,
+                  KitaDomTree* domtreeparent,
+                  int mode );
+    void showStatusBar( QString info );
+    void gotoAnchor( QString anc );
+    Kita::Thread* get2chThread() { return m_thread; }
+    int getViewMode() { return m_viewmode; }
+
+    /* !! static !! */
+    static KURL filterReadCGICore( const KURL&, Kita::Thread* thread );
+    static void getRefNumber( const KURL& url, Kita::Thread* thread,
+                              int& renNum, int& refNum2 );
+
+    /* for preview and KitaNavi */    
+    void domAppendData(QString& str,int bufnum,int num );
+    void domDeleteRes(int bufnum);
+    void domAppendBelt(QString idstr);
+    void domAppendHTML(QString& url,QString& html);
+    void domApplyChange(QString lbstr,QString hstr,QString fstr,QString anchor,QString cmbstr);
+    
 public slots:
     void showThread( const Kita::Thread* thread );
     void setFont( const QFont& font );
     void slotReloadButton();
+    void slotOpenURLRequest( const KURL&, const KParts::URLArgs& );
 
 protected slots:
     void slotDOMNodeActivated( const DOM::Node& node );
     void slotPopupMenu( KXMLGUIClient*, const QPoint&, const KURL&, const QString&, mode_t );
-    void slotOpenURLRequest( const KURL&, const KParts::URLArgs& );
 
-private:     // Private attributes
+private:       // Private attributes
     Kita::Access* m_access;
     Kita::Thread* m_thread;
     KitaHTMLPart* m_threadPart;
     Kita::PostInfo m_postInfo;
     Kita::ResPopup* m_popup;
 
+    KitaDomTree* m_domtree;
+    bool m_revsearch;
+    int m_viewmode;
+    int m_rescode;
+
+    /* for config */
+    int m_preShowNum;
+    int m_afterShowNum;
+    QString m_mailaddr;
+    int m_maxpopup;
+    QString m_style;
+    bool m_online;
+
+    /* for KitaNavi */
+    KitaDomTree* m_domtreeparent;
+    KitaThreadView* m_viewparent;
+
+    void update_readCache();
+    void update_rendering( bool breload );
+    void update_finish();
+    void update_copydata( const QString& linedata, int basenum );
+
+    void appendRes( int startnum, int endnum );
+    void showPopup( QString innerHTML, QString imgfile );
+    void slotWriteButtonClickedCore( QString resstr );
+
     void insertSearchCombo();
     KURL filterReadCGI( const KURL& );
     void setSubjectLabel( const QString& boardName, const QString& threadName );
     KitaWriteDialog* openDialog( const Kita::PostInfo& info );
     const QString footer() const;
     QStringList parseSearchQuery( const QString& input ) const;
-    void update( const QString& result );
     void updateButton();
 
 private slots:
@@ -121,6 +176,7 @@ namespace Kita
 
     class ResPopup : public QFrame
     {
+        KHTMLPart* m_part;
         Kita::PopupTextBrowser* m_browser;
     public:
         ResPopup( KHTMLView* view );
