@@ -19,6 +19,13 @@
 template <class type> class QPtrList;
 class KitaWriteDialogPrivate;
 class KitaWriteDialog;
+class KitaThreadView;
+class KitaDomTree;
+namespace Kita
+{
+    class Access;
+    class Thread;
+};
 
 /**
  * 
@@ -37,10 +44,20 @@ public:
     virtual bool error() { return false; };
 
     static KitaWriteDialog* open( const Kita::PostInfo& info, const Kita::Thread* thread );
+    void setupEx(
+        Kita::Thread* thread,
+        Kita::Access* access,
+        KitaThreadView* viewparent,
+        KitaDomTree* domtreeparent,
+        int num
+    );
 
 public slots:
     void postMessage();
 
+private slots:
+    void slotCurrentChanged ( QWidget * w );
+
 signals:
     void postStarted( KIO::Job*, const Kita::PostInfo& );
     void postFinished( KIO::Job* );
@@ -58,6 +75,9 @@ private:
     QCString m_array;
     bool m_error;
     static KitaWriteDialogPrivate* s_private;
+    KitaThreadView *m_preview;
+    int m_bufnum;
+    int m_resnum;
 
 private slots:
     void slotRecieveData( KIO::Job*, const QByteArray& );
