@@ -21,6 +21,7 @@
 #include <qpushbutton.h>
 #include <qlistbox.h>
 #include <qmessagebox.h>
+#include <qcheckbox.h>
 
 #include "kitafontprefbase.h"
 #include "kitaconfig.h"
@@ -50,6 +51,9 @@ KitaPreferences::KitaPreferences()
     QFrame * asciiArtFrame = addPage( i18n( "AsciiArt" ), i18n( "AsciiArt" ) );
     m_asciiArtPage = new Kita::AsciiArtPrefPage( asciiArtFrame );
 
+    QFrame * uiFrame = addPage( i18n( "User Interface" ), i18n( " User Interface" ) );
+    m_uiPage = new Kita::UIPrefPage( uiFrame );
+
     QFrame * debugFrame = addPage( i18n( "Debug" ), i18n( "Debug" ) );
     m_debugPage = new DebugPrefPage( debugFrame );
 }
@@ -192,6 +196,7 @@ void DebugPrefPage::replace()
         FavoriteThreads::replace( fromURL, toURL );
         Kita::Thread::replace( fromURL, toURL );
         KitaThreadInfo::replace( fromURL, toURL );
+        Kita::FavoriteBoards::replace( fromURL, toURL );
 
         QMessageBox::information( this, i18n( "replace" ), i18n( "Complete." ) );
     }
@@ -213,4 +218,15 @@ void AsciiArtPrefPage::commit()
     KitaConfig::setAsciiArtList( list );
 }
 
+UIPrefPage::UIPrefPage( QWidget* parent )
+        : UIPrefBase( parent )
+{
+    connect( useTabCheckBox, SIGNAL( toggled( bool ) ), SLOT( slotUseTabToggled( bool ) ) );
+}
+
+void UIPrefPage::slotUseTabToggled( bool on )
+{
+    KitaConfig::setAlwaysUseTab( on );
+}
+
 #include "pref.moc"
