@@ -17,10 +17,12 @@
 #include "kitafontprefbase.h"
 #include "kitacolorprefbase.h"
 #include "asciiartprefbase.h"
+#include "uiprefbase.h"
 #include "debugprefbase.h"
 
 #include "libkita/favoritethreads.h"
 #include "libkita/threadinfo.h"
+#include "libkita/favoriteboards.h"
 
 class KitaFontPrefPage;
 class KitaColorPrefPage;
@@ -29,6 +31,7 @@ class DebugPrefPage;
 namespace Kita
 {
     class AsciiArtPrefPage;
+    class UIPrefPage;
 };
 
 class KitaPreferences : public KDialogBase
@@ -42,6 +45,7 @@ private:
     KitaFontPrefPage* m_fontPage;
     KitaColorPrefPage* m_colorPage;
     Kita::AsciiArtPrefPage* m_asciiArtPage;
+    Kita::UIPrefPage* m_uiPage;
     DebugPrefPage* m_debugPage;
 
 signals:
@@ -100,6 +104,15 @@ namespace Kita
     public slots:
         void commit();
     };
+
+    class UIPrefPage : public UIPrefBase
+    {
+        Q_OBJECT
+    public:
+        UIPrefPage( QWidget* parent = 0 );
+    private slots:
+        void slotUseTabToggled( bool on );
+    };
 };
 
 #endif // _KITAPREF_H_
